<?php
/**
 * @package mod_tinydoc for Joomla! 3.x
 * @version $Id: default.php 2017-09-21 $
 * @author Andreas Thul
 * @copyright (c) 2012-2017 Andreas Thul
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

// 2014-09-16: changed DS to DIRECTORY_SEPARATOR

defined('_JEXEC') or die('Restricted access');

require_once(JPATH_ADMINISTRATOR . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_tinydoc' . DIRECTORY_SEPARATOR . 'helper.php');

// 2013-06-03: Only variables should be assigned by reference

if ($params->get('use_default_style')) {
	$doc = JFactory::getDocument();
	$doc->addStyleSheet(JURI::base() . '/modules/mod_tinydoc/assets/mod_tinydoc.css');
}

$class_table = $params->get('class_table');
$class_th = $params->get('class_th');
$class_tr_odd = $params->get('class_tr_odd');
$class_tr_even = $params->get('class_tr_even');

$icons = modTinyDocHelper::getTypeIcons();

// 2013-06-04: set default layout type to 'standard' if value is not set
if ($params->def('layout_type', 'standard') == 'standard') {

	echo "<table class=\"$class_table\">";
	echo "<tr class=\"$class_th\">";

		if ($params->get('show_icon')) {
			echo '<th></th>';
		}

		if ($params->get('show_name')) {
			echo '<th>' . JText::_('HEADER_NAME') .  '</th>';
		}

		if ($params->get('show_description')) {
			echo '<th>' . JText::_('HEADER_DESCRIPTION') .  '</th>';
		}

		if ($params->get('show_date')) {
			echo '<th>' . JText::_('HEADER_DATE') .  '</th>';
		}

		if ($params->get('show_size')) {
			echo '<th>' . JText::_('HEADER_SIZE') .  '</th>';
		}

	echo '<th></th>';

	echo '</tr>';

	$count = 0;

	foreach ($documents as $document) {

		if ($count % 2) {
			$class = $class_tr_odd;
		}
		else {
			$class = $class_tr_even;
		}

		$url = JRoute::_("index.php?option=com_tinydoc&view=document&document=" . $document->id . "&format=raw");

		echo "<tr class=\"$class\">";

		if ($params->get('show_icon')) {
			echo "<td><img src=\"" .  JURI::base() . "/components/com_tinydoc/assets/" . $icons[$document->type_id] . "\" /></td>";
		}

		if ($params->get('show_name')) {
			echo "<td>" . $document->name . "</td>";
		}

		if ($params->get('show_description')) {
			echo "<td>" . $document->description . "</td>";
		}

		// 2017-09-21: added nowrap to date display
		if ($params->get('show_date')) {
			echo "<td class=\"nowrap\">" . JHTML::date($document->date, $params->get('date_format', 'Y-m-d')) . "</td>";
		}

		if ($params->get('show_size')) {

			echo "<td>";

			if ($params->get('convert_size', 1)) {
				echo TinyDocHelper::getSizeAsText($document->size);
			}
			else {
				echo $document->size;
			}
			echo "</td>";
		}

		echo "<td><a href=\"$url\">" . JText::_('TEXT_DOWNLOAD') . "</a></td>";

		echo '</tr>';

		$count++;
	}

	echo '</table>';
}
else {

	echo $params->get('custom_layout_begin');

	foreach ($documents as $document) {

		$buffer = $params->get('custom_layout_item');

		if ($params->get('convert_size', 1)) {
			$size = TinyDocHelper::getSizeAsText($document->size);
		}
		else {
			$size = $document->size;
		}

		$buffer = preg_replace('/###date###/', JHTML::date($document->date, $params->get('date_format', 'Y-m-d')), $buffer);
		$buffer = preg_replace('/###description###/', $document->description, $buffer);
		$buffer = preg_replace('/###icon###/', JURI::base() . "/components/com_tinydoc/assets/" . $icons[$document->type_id], $buffer);
		$buffer = preg_replace('/###name###/', $document->name, $buffer);
		$buffer = preg_replace('/###size###/', $size, $buffer);
		$buffer = preg_replace('/###url###/', JRoute::_("index.php?option=com_tinydoc&view=document&document=" . $document->id . "&format=raw"), $buffer);

		echo $buffer;
	}

	echo $params->get('custom_layout_end');
}


?>
